@@ -2,11 +2,12 @@ import copy
 import json
 import os
 import re
+import warnings
 from collections.abc import Mapping
 from datetime import datetime
 from enum import StrEnum, auto
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, ClassVar, Self, cast
+from typing import Any, ClassVar, Self, cast
 from uuid import UUID
 
 from aviary.functional import EnvironmentBuilder
@@ -20,10 +21,6 @@ from pydantic import (
     model_validator,
 )
 
-if TYPE_CHECKING:
-    from futurehouse_client.clients import JobNames
-
-
 MAX_CROW_JOB_RUN_TIMEOUT = 60 * 60 * 24  # 24 hours in sec
 MIN_CROW_JOB_RUN_TIMEOUT = 0  # sec
 
@@ -35,6 +32,68 @@ class AuthType(StrEnum):
     JWT = auto()
 
 
+class JobNames(StrEnum):
+    """Enum of available jobs."""
+
+    CROW = "job-futurehouse-paperqa2"
+    FALCON = "job-futurehouse-paperqa2-deep"
+    OWL = "job-futurehouse-hasanyone"
+    DUMMY = "job-futurehouse-dummy-env"
+    PHOENIX = "job-futurehouse-phoenix"
+    FINCH = "job-futurehouse-data-analysis-crow-high"
+    CHIMP = "job-futurehouse-chimp"
+
+    @classmethod
+    def _get_response_mapping(cls) -> "dict[JobNames, type[TaskResponse]]":
+        return {
+            cls.CROW: PQATaskResponse,
+            cls.FALCON: PQATaskResponse,
+            cls.OWL: PQATaskResponse,
+            cls.CHIMP: PQATaskResponse,
+            cls.PHOENIX: PhoenixTaskResponse,
+            cls.FINCH: FinchTaskResponse,
+            cls.DUMMY: TaskResponse,
+        }
+
+    @classmethod
+    def from_stage(cls, job_name: str, stage: "Stage | None" = None) -> str:
+        if stage is None:
+            import logging
+
+            logger = logging.getLogger(__name__)
+            logger.warning(
+                "Stage is not provided, Stage.PROD as default stage. "
+                "Explicitly providing the stage is recommended."
+            )
+            stage = Stage.PROD
+        return cls.from_string(job_name).value
+
+    @classmethod
+    def from_string(cls, job_name: str) -> "JobNames":
+        try:
+            return cls[job_name.upper()]
+        except KeyError as e:
+            raise ValueError(
+                f"Invalid job name: {job_name}. \nOptions are: {', '.join([name.name for name in cls])}"
+            ) from e
+
+    @staticmethod
+    def get_response_object_from_job(
+        job_name: "str | JobNames",
+    ) -> "type[TaskResponse]":
+        try:
+            return JobNames(job_name).get_response_object(failover=TaskResponse)
+        except ValueError:
+            return TaskResponse
+
+    def get_response_object(
+        self, failover: "type[TaskResponse] | None" = None
+    ) -> "type[TaskResponse]":
+        if failover is None:
+            return self._get_response_mapping()[self]
+        return self._get_response_mapping().get(self, failover)
+
+
 class APIKeyPayload(BaseModel):
     api_key: str = Field(description="A user API key to authenticate with the server.")
 
@@ -357,6 +416,11 @@ class DockerContainerConfiguration(BaseModel):
         return self
 
 
+class CacheStrategy(StrEnum):
+    USE_CACHE = "use_cache"
+    NO_CACHE = "no_cache"
+
+
 class JobDeploymentConfig(BaseModel):
     model_config = ConfigDict(
         extra="forbid",
@@ -390,8 +454,10 @@ class JobDeploymentConfig(BaseModel):
 
     environment: str = Field(
         description="Your environment path, should be a module reference if we pass an environment. "
-        "Can be an arbitrary name if we are deploying a functional environment (through the functional_environment parameter). "
-        "example: dummy_env.env.DummyEnv",
+        "Can be an arbitrary name if we are deploying a functional environment "
+        "(through the functional_environment parameter). "
+        "This path does not have to be importable locally, just in the job's container.",
+        examples=["aviary.env.DummyEnv"],
     )
 
     functional_environment: EnvironmentBuilder | None = Field(
@@ -450,8 +516,20 @@ class JobDeploymentConfig(BaseModel):
         default="storage",
         description="The location the container will use to mount a locally accessible GCS folder as a volume. "
         "This location can be used to store and fetch files safely without GCS apis or direct access.",
+        deprecated=True,
     )
 
+    @field_validator("storage_location")
+    @classmethod
+    def warn_storage_dir_deprecated(cls, v):
+        warnings.warn(
+            "The 'storage_location' has been deprecated and this feature is no longer supported. "
+            "If your job requires storage, please use the data-storage api to store artifacts.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        return v
+
     frame_paths: list[FramePath] | None = Field(
         default=None,
         description="List of FramePath which indicates where to find important frame data, and how to render it.",
@@ -477,6 +555,10 @@ class JobDeploymentConfig(BaseModel):
             "These will be used to prompt users for values during query submission."
         ),
     )
+    cache_strategy: CacheStrategy = Field(
+        default=CacheStrategy.USE_CACHE,
+        description="The cache strategy to use for the task",
+    )
 
     @field_validator("markdown_template_path")
     @classmethod
@@ -600,7 +682,7 @@ class RuntimeConfig(BaseModel):
     This advanced configuration is only available for supported crows.
     """
 
-    model_config = ConfigDict(arbitrary_types_allowed=True)
+    model_config = ConfigDict(arbitrary_types_allowed=True, extra="forbid")
 
     upload_id: str | None = Field(
         default=None,
@@ -734,7 +816,7 @@ class TaskRequest(BaseModel):
         default=None,
         description="Optional group identifier for the task",
     )
-    name: "str | JobNames" = Field(
+    name: str | JobNames = Field(
         description="Name of the crow to execute eg. paperqa-crow"
     )
     query: str = Field(description="Query or task to be executed by the crow")
@@ -775,12 +857,13 @@ class TaskResponse(BaseModel):
     user: str | None = None
     created_at: datetime
     job_name: str
-    public: bool
-    shared_with: list[SimpleOrganization] | None = None
+    share_status: str
+    permitted_accessors: dict[str, list[str | int]] | None = None
     build_owner: str | None = None
     environment_name: str | None = None
     agent_name: str | None = None
     task_id: UUID | None = None
+    project_id: UUID | None = None
 
     @model_validator(mode="before")
     @classmethod
@@ -910,8 +993,8 @@ class TaskResponseVerbose(TaskResponse):
 
     model_config = ConfigDict(extra="allow")
 
-    public: bool
+    share_status: str
     agent_state: list[dict[str, Any]] | None = None
     environment_frame: dict[str, Any] | None = None
     metadata: dict[str, Any] | None = None
-    shared_with: list[SimpleOrganization] | None = None
+    permitted_accessors: dict[str, list[str | int]] | None = None
