@@ -145,7 +145,7 @@ def test_task_response_does_not_mutate_original_data():
         },
         "status": "success",
         "created_at": datetime.now(),
-        "public": True,
+        "share_status": "PUBLIC",
     }
 
     original_data_copy = copy.deepcopy(original_data)
