@@ -15,14 +15,14 @@ from futurehouse_client.models.app import (
 )
 from futurehouse_client.models.data_storage_methods import (
     DataContentType,
-    DataStorageEntryPermittedAccessors,
     DataStorageLocationPayload,
-    DataStorageShareStatus,
     DataStorageType,
+    PermittedAccessors,
     RawFetchResponse,
+    ShareStatus,
 )
 from futurehouse_client.models.rest import (
-    # FilterLogic,
+    FilterLogic,
     SearchCriterion,
     SearchOperator,
 )
@@ -606,7 +606,7 @@ class TestDataStorageSearch:
             field="name", operator=SearchOperator.CONTAINS, value=test_query
         )
 
-        results = admin_client.search_data_storage(criteria=[test_criteria], size=5)
+        results = admin_client.search_data_storage(criteria=[test_criteria], limit=5)
 
         assert results is not None
         assert len(results) == 5
@@ -622,68 +622,68 @@ class TestDataStorageSearch:
         )
 
         results = await admin_client.asearch_data_storage(
-            criteria=[name_test_criteria], size=5
+            criteria=[name_test_criteria], limit=5
         )
 
         assert results is not None
         assert len(results) == 5
         assert test_query.lower() in results[0]["name"].lower()
 
-    # @pytest.mark.timeout(300)
-    # @pytest.mark.asyncio
-    # async def test_complex_data_storage_search_async(self, admin_client: RestClient):
-    #     test_query = "test"
+    @pytest.mark.timeout(300)
+    @pytest.mark.asyncio
+    async def test_complex_data_storage_search_async(self, admin_client: RestClient):
+        test_query = "test"
 
-    #     name_test_criteria = SearchCriterion(
-    #         field="name", operator=SearchOperator.CONTAINS, value=test_query
-    #     )
+        name_test_criteria = SearchCriterion(
+            field="name", operator=SearchOperator.CONTAINS, value=test_query
+        )
 
-    #     user_id_test_criteria = SearchCriterion(
-    #         field="user_id",
-    #         operator=SearchOperator.EQUALS,
-    #         value="a5E0sDbOYEWLBoy9qzOQ8yfKiKw1",
-    #     )
+        user_id_test_criteria = SearchCriterion(
+            field="user_id",
+            operator=SearchOperator.EQUALS,
+            value="a5E0sDbOYEWLBoy9qzOQ8yfKiKw1",
+        )
 
-    #     dataset_id_test_criteria = SearchCriterion(
-    #         field="dataset_id",
-    #         operator=SearchOperator.EQUALS,
-    #         value="8bb27d71-8ec6-4845-a09e-4eceefb38cba",
-    #     )
+        dataset_id_test_criteria = SearchCriterion(
+            field="dataset_id",
+            operator=SearchOperator.EQUALS,
+            value="8bb27d71-8ec6-4845-a09e-4eceefb38cba",
+        )
 
-    #     description_test_criteria = SearchCriterion(
-    #         field="description",
-    #         operator=SearchOperator.CONTAINS,
-    #         value="xyz.api.futurehouse.org",
-    #     )
+        description_test_criteria = SearchCriterion(
+            field="description",
+            operator=SearchOperator.CONTAINS,
+            value="xyz.api.futurehouse.org",
+        )
 
-    #     or_results = await admin_client.asearch_data_storage(
-    #         criteria=[
-    #             name_test_criteria,
-    #             user_id_test_criteria,
-    #             dataset_id_test_criteria,
-    #             description_test_criteria,
-    #         ],
-    #         filter_logic=FilterLogic.OR,
-    #     )
+        or_results = await admin_client.asearch_data_storage(
+            criteria=[
+                name_test_criteria,
+                user_id_test_criteria,
+                dataset_id_test_criteria,
+                description_test_criteria,
+            ],
+            filter_logic=FilterLogic.OR,
+        )
 
-    #     and_results = await admin_client.asearch_data_storage(
-    #         criteria=[
-    #             name_test_criteria,
-    #             user_id_test_criteria,
-    #             dataset_id_test_criteria,
-    #             description_test_criteria,
-    #         ],
-    #         filter_logic=FilterLogic.AND,
-    #     )
+        and_results = await admin_client.asearch_data_storage(
+            criteria=[
+                name_test_criteria,
+                user_id_test_criteria,
+                dataset_id_test_criteria,
+                description_test_criteria,
+            ],
+            filter_logic=FilterLogic.AND,
+        )
 
-    #     assert or_results is not None
-    #     assert len(or_results) > 0
+        assert or_results is not None
+        assert len(or_results) > 0
 
-    #     assert and_results is not None
-    #     assert len(and_results) > 0
-    #     assert test_query.lower() in and_results[0]["name"].lower()
+        assert and_results is not None
+        assert len(and_results) > 0
+        assert test_query.lower() in and_results[0]["name"].lower()
 
-    #     assert len(or_results) > len(and_results)
+        assert len(or_results) > len(and_results)
 
 
 class TestEntryPermissions:
@@ -700,27 +700,21 @@ class TestEntryPermissions:
             description="Here is some description",
         )
 
-        assert (
-            create_entry_response.data_storage.share_status
-            == DataStorageShareStatus.PRIVATE
-        )
+        assert create_entry_response.data_storage.share_status == ShareStatus.PRIVATE
 
         with pytest.raises(DataStorageError, match="Data storage entry not found"):
             pub_client.fetch_data_from_storage(create_entry_response.data_storage.id)
 
         update_entry_response = admin_client.update_entry_permissions(
             data_storage_id=create_entry_response.data_storage.id,
-            share_status=DataStorageShareStatus.PUBLIC,
-            permitted_accessors=DataStorageEntryPermittedAccessors(
+            share_status=ShareStatus.PUBLIC,
+            permitted_accessors=PermittedAccessors(
                 users=[],
                 organizations=[],
             ),
         )
 
-        assert (
-            update_entry_response.data_storage.share_status
-            == DataStorageShareStatus.PUBLIC
-        )
+        assert update_entry_response.data_storage.share_status == ShareStatus.PUBLIC
 
         fetch_entry_response = admin_client.fetch_data_from_storage(
             create_entry_response.data_storage.id
@@ -749,10 +743,7 @@ class TestEntryPermissions:
             description="Here is some description",
         )
 
-        assert (
-            create_entry_response.data_storage.share_status
-            == DataStorageShareStatus.PRIVATE
-        )
+        assert create_entry_response.data_storage.share_status == ShareStatus.PRIVATE
 
         with pytest.raises(DataStorageError, match="Data storage entry not found"):
             await pub_client.afetch_data_from_storage(
@@ -761,8 +752,8 @@ class TestEntryPermissions:
 
         update_entry_response = await admin_client.aupdate_entry_permissions(
             data_storage_id=create_entry_response.data_storage.id,
-            share_status=DataStorageShareStatus.PUBLIC,
-            permitted_accessors=DataStorageEntryPermittedAccessors(
+            share_status=ShareStatus.PUBLIC,
+            permitted_accessors=PermittedAccessors(
                 users=[],
                 organizations=[],
             ),
@@ -779,10 +770,7 @@ class TestEntryPermissions:
             fetch_entry_response.entry_name == create_entry_response.data_storage.name
         )
 
-        assert (
-            update_entry_response.data_storage.share_status
-            == DataStorageShareStatus.PUBLIC
-        )
+        assert update_entry_response.data_storage.share_status == ShareStatus.PUBLIC
 
         await admin_client.adelete_data_storage_entry(
             create_entry_response.data_storage.id
