@@ -73,6 +73,7 @@ class TestDataStorageMethods:
                 "modified_at": now,
                 "content": content,
                 "status": "active",
+                "share_status": "private",
             },
             "storage_locations": [
                 {
@@ -285,7 +286,15 @@ class TestDataStorageMethods:
             temp_file.flush()
 
             file_size, payload = self.methods._prepare_single_file_upload(
-                "test.txt", Path(temp_file.name), "Test description", None
+                name="test.txt",
+                file_path=Path(temp_file.name),
+                description="Test description",
+                file_path_override=None,
+                dataset_id=None,
+                project_id=None,
+                metadata=None,
+                tags=None,
+                parent_id=None,
             )
 
             assert file_size > 0
@@ -301,7 +310,15 @@ class TestDataStorageMethods:
             temp_file.flush()
 
             file_size, payload = self.methods._prepare_single_file_upload(
-                "large.bin", Path(temp_file.name), "Large file", None
+                name="large.bin",
+                file_path=Path(temp_file.name),
+                description="Large file",
+                file_path_override=None,
+                dataset_id=None,
+                project_id=None,
+                metadata=None,
+                tags=None,
+                parent_id=None,
             )
 
             assert file_size > 0
@@ -1074,6 +1091,7 @@ class TestDataStorageMethods:
                     "user_id": "test_user_123",
                     "created_at": "2024-01-01T00:00:00Z",
                     "modified_at": "2024-01-01T00:00:00Z",
+                    "share_status": "private",
                 }
             ],
         }
@@ -1271,6 +1289,7 @@ class TestDataStorageMethods:
                     "user_id": "test_user_123",
                     "created_at": "2024-01-01T00:00:00Z",
                     "modified_at": "2024-01-01T00:00:00Z",
+                    "share_status": "private",
                 }
             ],
         }
